Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1222)

Unified Diff: Source/core/loader/DocumentWriter.h

Issue 495743003: Add an extra guard to replaceDocument() (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Landing Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/loader/DocumentLoader.cpp ('k') | Source/core/loader/FrameLoader.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/loader/DocumentWriter.h
diff --git a/Source/core/loader/DocumentWriter.h b/Source/core/loader/DocumentWriter.h
index c4bb7589945b4b925da54245ef97059fed9a27c9..4c942c6b73bb057d062878fb074df505822b6596 100644
--- a/Source/core/loader/DocumentWriter.h
+++ b/Source/core/loader/DocumentWriter.h
@@ -55,14 +55,14 @@ public:
// This is only called by ScriptController::executeScriptIfJavaScriptURL
// and always contains the result of evaluating a javascript: url.
- void replaceDocument(const String&, Document* ownerDocument);
+ void replaceDocumentWhileExecutingJavaScriptURL(const String&, Document* ownerDocument);
void addData(const char* bytes, size_t length);
const AtomicString& mimeType() const { return m_decoderBuilder.mimeType(); }
const AtomicString& encoding() const { return m_decoderBuilder.encoding(); }
// Exposed for DocumentLoader::replaceDocument.
void appendReplacingData(const String&);
void setUserChosenEncoding(const String& charset);
« no previous file with comments | « Source/core/loader/DocumentLoader.cpp ('k') | Source/core/loader/FrameLoader.h » ('j') | no next file with comments »
@@ -55,14 +55,14 @@ public:
const AtomicString& mimeType() const { return m_decoderBuilder.mimeType(); }
const AtomicString& encoding() const { return m_decoderBuilder.encoding(); }
- // Exposed for DocumentLoader::replaceDocument.
+ // Exposed for DocumentLoader::replaceDocumentWhileExecutingJavaScriptURL.
void appendReplacingData(const String&);
void setUserChosenEncoding(const String& charset);

Powered by Google App Engine
This is Rietveld 408576698